import classNames from 'classnames';
import { useTranslation } from 'react-i18next';
import { useAutobone } from '../../../../../hooks/autobone';
import { Button } from '../../../../commons/Button';
import { Typography } from '../../../../commons/Typography';

export function VerifyResultsStep({
  nextStep,
  prevStep,
  variant,
}: {
  nextStep: () => void;
  prevStep: () => void;
  variant: 'onboarding' | 'alone';
}) {
  const { t } = useTranslation();
  const {
    startRecording,
    hasCalibration,
    bodyParts,
    hasRecording,
    applyProcessing,
  } = useAutobone();

  const apply = () => {
    applyProcessing();
    nextStep();
  };

  const redo = () => {
    startRecording();
    prevStep();
  };

  return (
    <>
      <div className="flex flex-col flex-grow justify-between gap-1">
        <div className="flex flex-col gap-1 max-w-sm">
          <Typography variant="main-title" bold>
            {t('onboarding.automatic-proportions.verify-results.title')}
          </Typography>
          <div>
            <Typography color="secondary">
              {t('onboarding.automatic-proportions.verify-results.description')}
            </Typography>
          </div>
        </div>
        <div className="flex w-full items-center flex-col">
          <div className="flex flex-col pt-1 gap-2 justify-center w-full max-w-xs">
            <Typography bold>
              {t('onboarding.automatic-proportions.verify-results.results')}
            </Typography>
            <div
              className={classNames(
                'flex flex-col  w-full p-4 rounded-md gap-2',
                variant === 'onboarding' && 'bg-background-60',
                variant === 'alone' && 'bg-background-50'
              )}
            >
              {bodyParts?.map(({ bone, label, value }) => (
                <div className="flex justify-between" key={bone}>
                  <Typography color="secondary">{label}</Typography>
                  <Typography bold>{(value * 100).toFixed(2)} CM</Typography>
                </div>
              ))}
              {!hasCalibration && hasRecording && (
                <Typography>
                  {t(
                    'onboarding.automatic-proportions.verify-results.processing'
                  )}
                </Typography>
              )}
            </div>
          </div>
        </div>
        <div className="flex gap-2">
          <Button
            variant={variant === 'onboarding' ? 'secondary' : 'tiertiary'}
            onClick={redo}
          >
            {t('onboarding.automatic-proportions.verify-results.redo')}
          </Button>
          <Button variant="primary" onClick={apply}>
            {t('onboarding.automatic-proportions.verify-results.confirm')}
          </Button>
        </div>
      </div>
    </>
  );
}
